#!/bin/bash
# This is a sample `notefile.cmd` Linux bash script to be called from NOTEFILE.
# © 2021 Fedon Kadifeli.
# You can freely edit this file. For more info:
# https://kadifeli.com/fedon/notefile.php/T_RELOAD
# Note: Some commands called by this script may not be available in your system.

export LANG="en_US.UTF-8"	# For non-ASCII UTF-8 character input

case "$1" in
 1 ) ## Sort input lines:
   sort
   ;;
 2 ) ## Fill to the max size (500,000 characters) of a card:
   for (( i=0; i<5000; i++ )) ; do
     printf "123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789\n"
   done
   ;;
 3 ) ## Pipe input to `bc` to calculate a math expression:
   bc -l
   ;;
 4 ) ## Pipe input to `gnome-calculator` to calculate a math expression:
   gnome-calculator -s "$(cat)"
   ;;
 14 ) ## Echo date in a specific format:
   date +"%a %b %d %T %z %Y"
   ;;
 15 ) ## Count the new lines, words, UTF-8 characters and bytes
      ##  in input and display the output to stderr:
   printf "Lines/Words/Chars/Bytes:\n" >&2
   wc -wlmc >&2
   exit 0
   ;;
 16 ) ## Convert IP to country information:
   out="$(curl -sS https://freegeoip.app/json/"$(cat -)")"
     ## Or: curl -sS https://api.ip2country.info/ip?"$(cat -)"
   out="${out#\{}"
   out="${out%\}}"
   printf "$out\n" | tr ',' '\n' | sed -e 's/:/ : /' -e 's/"//g'
   ## Or, better, use `jq` to parse the output as in the next example. 
   ;;
 17 ) ## Convert Country_Code/ZIP to place information:
      ##  Sample input data: US/97818 or TR/34746
   curl -sS https://api.zippopotam.us/"$(cat -)" | jq -r '.places[] | (to_entries[] | "\(.key) : \(.value)"), ""'
   ;;
 19 ) ## Just for test:
   printf "Going to sleep..."
   sleep 1.5
   printf ' Woke up!'"\n"
   ;;
121 ) ## Execute `ls` with given "parameter":
   /bin/ls $2
   ;;
122 ) ## Run the given "parameter" as a complete command:
   $2
   ;;
 23 ) ## Return error code:
   ##  printf "This is an error!\n" >&2
   exit 33
   ;;
 '' )
   cat <<EOT
  1 &Sort
  2 &Fill Card
  3 Calculate E&xpresssion with bc
  4 Calculate Expresssion with &gnome-calculator
 14 Insert &Date && Time
 15 Character, Word && Line &Count...
 16 Convert &IP to Region
 17 Convert Country_Code/&ZIP to Place Info
 19 &Sleep
121 "ls" With &Parameter
122 &Any Command
 23 &Error...
EOT
   exit 0
   ;;
  * )
   printf "Unknown parameter (%.3s)!\n" "$1" >&2
   exit 255
esac

